# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Attribute(object):
    """
    Attribute
    """

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_FIVE"
    MAXIMUM_LEN_LENGTH_FIVE = "LENGTH_FIVE"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_SIXTEEN"
    MAXIMUM_LEN_LENGTH_SIXTEEN = "LENGTH_SIXTEEN"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_THIRTYTWO"
    MAXIMUM_LEN_LENGTH_THIRTYTWO = "LENGTH_THIRTYTWO"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_SIXTYFOUR"
    MAXIMUM_LEN_LENGTH_SIXTYFOUR = "LENGTH_SIXTYFOUR"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_ONETWOEIGHT"
    MAXIMUM_LEN_LENGTH_ONETWOEIGHT = "LENGTH_ONETWOEIGHT"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_TWOFIFTYSIX"
    MAXIMUM_LEN_LENGTH_TWOFIFTYSIX = "LENGTH_TWOFIFTYSIX"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_FIVETWELVE"
    MAXIMUM_LEN_LENGTH_FIVETWELVE = "LENGTH_FIVETWELVE"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_SEVENFIFTY"
    MAXIMUM_LEN_LENGTH_SEVENFIFTY = "LENGTH_SEVENFIFTY"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_ONE_THOUSAND"
    MAXIMUM_LEN_LENGTH_ONE_THOUSAND = "LENGTH_ONE_THOUSAND"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_TWO_THOUSAND"
    MAXIMUM_LEN_LENGTH_TWO_THOUSAND = "LENGTH_TWO_THOUSAND"

    #: A constant which can be used with the maximum_len property of a Attribute.
    #: This constant has a value of "LENGTH_FOUR_THOUSAND"
    MAXIMUM_LEN_LENGTH_FOUR_THOUSAND = "LENGTH_FOUR_THOUSAND"

    #: A constant which can be used with the populated_by property of a Attribute.
    #: This constant has a value of "BACKEND_GEN"
    POPULATED_BY_BACKEND_GEN = "BACKEND_GEN"

    #: A constant which can be used with the populated_by property of a Attribute.
    #: This constant has a value of "CALLER_GEN"
    POPULATED_BY_CALLER_GEN = "CALLER_GEN"

    #: A constant which can be used with the required_in_json property of a Attribute.
    #: This constant has a value of "MANDATORY"
    REQUIRED_IN_JSON_MANDATORY = "MANDATORY"

    #: A constant which can be used with the required_in_json property of a Attribute.
    #: This constant has a value of "OPTIONAL"
    REQUIRED_IN_JSON_OPTIONAL = "OPTIONAL"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "CREATE"
    USAGE_SENARIO_CREATE = "CREATE"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "UPDATE"
    USAGE_SENARIO_UPDATE = "UPDATE"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "CREATE_AND_UPDATE"
    USAGE_SENARIO_CREATE_AND_UPDATE = "CREATE_AND_UPDATE"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "DELETE"
    USAGE_SENARIO_DELETE = "DELETE"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "RE_CREATE"
    USAGE_SENARIO_RE_CREATE = "RE_CREATE"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "DETAIL"
    USAGE_SENARIO_DETAIL = "DETAIL"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "LIST"
    USAGE_SENARIO_LIST = "LIST"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "FUNCTION_WITH_LOOKUP"
    USAGE_SENARIO_FUNCTION_WITH_LOOKUP = "FUNCTION_WITH_LOOKUP"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "DB_PATTERN"
    USAGE_SENARIO_DB_PATTERN = "DB_PATTERN"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "CREATE_FIRSTTIME_T1"
    USAGE_SENARIO_CREATE_FIRSTTIME_T1 = "CREATE_FIRSTTIME_T1"

    #: A constant which can be used with the usage_senario property of a Attribute.
    #: This constant has a value of "UPDATE_OOB_METRIC"
    USAGE_SENARIO_UPDATE_OOB_METRIC = "UPDATE_OOB_METRIC"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "INTEGER"
    VALUE_DATA_TYPE_INTEGER = "INTEGER"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "LONG"
    VALUE_DATA_TYPE_LONG = "LONG"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "FLOAT"
    VALUE_DATA_TYPE_FLOAT = "FLOAT"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "STRING"
    VALUE_DATA_TYPE_STRING = "STRING"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "TIMESTAMP"
    VALUE_DATA_TYPE_TIMESTAMP = "TIMESTAMP"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "DATE"
    VALUE_DATA_TYPE_DATE = "DATE"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "CLOB"
    VALUE_DATA_TYPE_CLOB = "CLOB"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "TAG_REF"
    VALUE_DATA_TYPE_TAG_REF = "TAG_REF"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "PARSER_REF"
    VALUE_DATA_TYPE_PARSER_REF = "PARSER_REF"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "STT_REF"
    VALUE_DATA_TYPE_STT_REF = "STT_REF"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "LOOKUP_REF"
    VALUE_DATA_TYPE_LOOKUP_REF = "LOOKUP_REF"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "META_FUNCTION_REF"
    VALUE_DATA_TYPE_META_FUNCTION_REF = "META_FUNCTION_REF"

    #: A constant which can be used with the value_data_type property of a Attribute.
    #: This constant has a value of "COMMON_FIELD_REF"
    VALUE_DATA_TYPE_COMMON_FIELD_REF = "COMMON_FIELD_REF"

    #: A constant which can be used with the value_population_priority property of a Attribute.
    #: This constant has a value of "NONE"
    VALUE_POPULATION_PRIORITY_NONE = "NONE"

    #: A constant which can be used with the value_population_priority property of a Attribute.
    #: This constant has a value of "LOW"
    VALUE_POPULATION_PRIORITY_LOW = "LOW"

    #: A constant which can be used with the value_population_priority property of a Attribute.
    #: This constant has a value of "HIGH"
    VALUE_POPULATION_PRIORITY_HIGH = "HIGH"

    def __init__(self, **kwargs):
        """
        Initializes a new Attribute object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param default_value:
            The value to assign to the default_value property of this Attribute.
        :type default_value: object

        :param dynamic_value_range_ref_attr:
            The value to assign to the dynamic_value_range_ref_attr property of this Attribute.
        :type dynamic_value_range_ref_attr: str

        :param maximum_len:
            The value to assign to the maximum_len property of this Attribute.
            Allowed values for this property are: "LENGTH_FIVE", "LENGTH_SIXTEEN", "LENGTH_THIRTYTWO", "LENGTH_SIXTYFOUR", "LENGTH_ONETWOEIGHT", "LENGTH_TWOFIFTYSIX", "LENGTH_FIVETWELVE", "LENGTH_SEVENFIFTY", "LENGTH_ONE_THOUSAND", "LENGTH_TWO_THOUSAND", "LENGTH_FOUR_THOUSAND"
        :type maximum_len: str

        :param name:
            The value to assign to the name property of this Attribute.
        :type name: str

        :param populated_by:
            The value to assign to the populated_by property of this Attribute.
            Allowed values for this property are: "BACKEND_GEN", "CALLER_GEN"
        :type populated_by: str

        :param required_in_json:
            The value to assign to the required_in_json property of this Attribute.
            Allowed values for this property are: "MANDATORY", "OPTIONAL"
        :type required_in_json: str

        :param schema_column:
            The value to assign to the schema_column property of this Attribute.
        :type schema_column: str

        :param is_string_exceed_maximum_length:
            The value to assign to the is_string_exceed_maximum_length property of this Attribute.
        :type is_string_exceed_maximum_length: bool

        :param usage_senario:
            The value to assign to the usage_senario property of this Attribute.
            Allowed values for this property are: "CREATE", "UPDATE", "CREATE_AND_UPDATE", "DELETE", "RE_CREATE", "DETAIL", "LIST", "FUNCTION_WITH_LOOKUP", "DB_PATTERN", "CREATE_FIRSTTIME_T1", "UPDATE_OOB_METRIC"
        :type usage_senario: str

        :param value_data_type:
            The value to assign to the value_data_type property of this Attribute.
            Allowed values for this property are: "INTEGER", "LONG", "FLOAT", "STRING", "TIMESTAMP", "DATE", "CLOB", "TAG_REF", "PARSER_REF", "STT_REF", "LOOKUP_REF", "META_FUNCTION_REF", "COMMON_FIELD_REF"
        :type value_data_type: str

        :param value_population_priority:
            The value to assign to the value_population_priority property of this Attribute.
            Allowed values for this property are: "NONE", "LOW", "HIGH"
        :type value_population_priority: str

        """
        self.swagger_types = {
            'default_value': 'object',
            'dynamic_value_range_ref_attr': 'str',
            'maximum_len': 'str',
            'name': 'str',
            'populated_by': 'str',
            'required_in_json': 'str',
            'schema_column': 'str',
            'is_string_exceed_maximum_length': 'bool',
            'usage_senario': 'str',
            'value_data_type': 'str',
            'value_population_priority': 'str'
        }

        self.attribute_map = {
            'default_value': 'defaultValue',
            'dynamic_value_range_ref_attr': 'dynamicValueRangeRefAttr',
            'maximum_len': 'maximumLen',
            'name': 'name',
            'populated_by': 'populatedBy',
            'required_in_json': 'requiredInJSON',
            'schema_column': 'schemaColumn',
            'is_string_exceed_maximum_length': 'isStringExceedMaximumLength',
            'usage_senario': 'usageSenario',
            'value_data_type': 'valueDataType',
            'value_population_priority': 'valuePopulationPriority'
        }

        self._default_value = None
        self._dynamic_value_range_ref_attr = None
        self._maximum_len = None
        self._name = None
        self._populated_by = None
        self._required_in_json = None
        self._schema_column = None
        self._is_string_exceed_maximum_length = None
        self._usage_senario = None
        self._value_data_type = None
        self._value_population_priority = None

    @property
    def default_value(self):
        """
        Gets the default_value of this Attribute.
        default value


        :return: The default_value of this Attribute.
        :rtype: object
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this Attribute.
        default value


        :param default_value: The default_value of this Attribute.
        :type: object
        """
        self._default_value = default_value

    @property
    def dynamic_value_range_ref_attr(self):
        """
        Gets the dynamic_value_range_ref_attr of this Attribute.
        dynamic value range reference attribute


        :return: The dynamic_value_range_ref_attr of this Attribute.
        :rtype: str
        """
        return self._dynamic_value_range_ref_attr

    @dynamic_value_range_ref_attr.setter
    def dynamic_value_range_ref_attr(self, dynamic_value_range_ref_attr):
        """
        Sets the dynamic_value_range_ref_attr of this Attribute.
        dynamic value range reference attribute


        :param dynamic_value_range_ref_attr: The dynamic_value_range_ref_attr of this Attribute.
        :type: str
        """
        self._dynamic_value_range_ref_attr = dynamic_value_range_ref_attr

    @property
    def maximum_len(self):
        """
        Gets the maximum_len of this Attribute.
        maximum length

        Allowed values for this property are: "LENGTH_FIVE", "LENGTH_SIXTEEN", "LENGTH_THIRTYTWO", "LENGTH_SIXTYFOUR", "LENGTH_ONETWOEIGHT", "LENGTH_TWOFIFTYSIX", "LENGTH_FIVETWELVE", "LENGTH_SEVENFIFTY", "LENGTH_ONE_THOUSAND", "LENGTH_TWO_THOUSAND", "LENGTH_FOUR_THOUSAND"


        :return: The maximum_len of this Attribute.
        :rtype: str
        """
        return self._maximum_len

    @maximum_len.setter
    def maximum_len(self, maximum_len):
        """
        Sets the maximum_len of this Attribute.
        maximum length


        :param maximum_len: The maximum_len of this Attribute.
        :type: str
        """
        allowed_values = ["LENGTH_FIVE", "LENGTH_SIXTEEN", "LENGTH_THIRTYTWO", "LENGTH_SIXTYFOUR", "LENGTH_ONETWOEIGHT", "LENGTH_TWOFIFTYSIX", "LENGTH_FIVETWELVE", "LENGTH_SEVENFIFTY", "LENGTH_ONE_THOUSAND", "LENGTH_TWO_THOUSAND", "LENGTH_FOUR_THOUSAND"]
        if not value_allowed_none_or_none_sentinel(maximum_len, allowed_values):
            raise ValueError(
                "Invalid value for `maximum_len`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._maximum_len = maximum_len

    @property
    def name(self):
        """
        Gets the name of this Attribute.
        name


        :return: The name of this Attribute.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Attribute.
        name


        :param name: The name of this Attribute.
        :type: str
        """
        self._name = name

    @property
    def populated_by(self):
        """
        Gets the populated_by of this Attribute.
        populated by

        Allowed values for this property are: "BACKEND_GEN", "CALLER_GEN"


        :return: The populated_by of this Attribute.
        :rtype: str
        """
        return self._populated_by

    @populated_by.setter
    def populated_by(self, populated_by):
        """
        Sets the populated_by of this Attribute.
        populated by


        :param populated_by: The populated_by of this Attribute.
        :type: str
        """
        allowed_values = ["BACKEND_GEN", "CALLER_GEN"]
        if not value_allowed_none_or_none_sentinel(populated_by, allowed_values):
            raise ValueError(
                "Invalid value for `populated_by`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._populated_by = populated_by

    @property
    def required_in_json(self):
        """
        Gets the required_in_json of this Attribute.
        required in JSON

        Allowed values for this property are: "MANDATORY", "OPTIONAL"


        :return: The required_in_json of this Attribute.
        :rtype: str
        """
        return self._required_in_json

    @required_in_json.setter
    def required_in_json(self, required_in_json):
        """
        Sets the required_in_json of this Attribute.
        required in JSON


        :param required_in_json: The required_in_json of this Attribute.
        :type: str
        """
        allowed_values = ["MANDATORY", "OPTIONAL"]
        if not value_allowed_none_or_none_sentinel(required_in_json, allowed_values):
            raise ValueError(
                "Invalid value for `required_in_json`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._required_in_json = required_in_json

    @property
    def schema_column(self):
        """
        Gets the schema_column of this Attribute.
        schema column


        :return: The schema_column of this Attribute.
        :rtype: str
        """
        return self._schema_column

    @schema_column.setter
    def schema_column(self, schema_column):
        """
        Sets the schema_column of this Attribute.
        schema column


        :param schema_column: The schema_column of this Attribute.
        :type: str
        """
        self._schema_column = schema_column

    @property
    def is_string_exceed_maximum_length(self):
        """
        Gets the is_string_exceed_maximum_length of this Attribute.
        is string exceed maximum length


        :return: The is_string_exceed_maximum_length of this Attribute.
        :rtype: bool
        """
        return self._is_string_exceed_maximum_length

    @is_string_exceed_maximum_length.setter
    def is_string_exceed_maximum_length(self, is_string_exceed_maximum_length):
        """
        Sets the is_string_exceed_maximum_length of this Attribute.
        is string exceed maximum length


        :param is_string_exceed_maximum_length: The is_string_exceed_maximum_length of this Attribute.
        :type: bool
        """
        self._is_string_exceed_maximum_length = is_string_exceed_maximum_length

    @property
    def usage_senario(self):
        """
        Gets the usage_senario of this Attribute.
        usage senario

        Allowed values for this property are: "CREATE", "UPDATE", "CREATE_AND_UPDATE", "DELETE", "RE_CREATE", "DETAIL", "LIST", "FUNCTION_WITH_LOOKUP", "DB_PATTERN", "CREATE_FIRSTTIME_T1", "UPDATE_OOB_METRIC"


        :return: The usage_senario of this Attribute.
        :rtype: str
        """
        return self._usage_senario

    @usage_senario.setter
    def usage_senario(self, usage_senario):
        """
        Sets the usage_senario of this Attribute.
        usage senario


        :param usage_senario: The usage_senario of this Attribute.
        :type: str
        """
        allowed_values = ["CREATE", "UPDATE", "CREATE_AND_UPDATE", "DELETE", "RE_CREATE", "DETAIL", "LIST", "FUNCTION_WITH_LOOKUP", "DB_PATTERN", "CREATE_FIRSTTIME_T1", "UPDATE_OOB_METRIC"]
        if not value_allowed_none_or_none_sentinel(usage_senario, allowed_values):
            raise ValueError(
                "Invalid value for `usage_senario`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._usage_senario = usage_senario

    @property
    def value_data_type(self):
        """
        Gets the value_data_type of this Attribute.
        value data type

        Allowed values for this property are: "INTEGER", "LONG", "FLOAT", "STRING", "TIMESTAMP", "DATE", "CLOB", "TAG_REF", "PARSER_REF", "STT_REF", "LOOKUP_REF", "META_FUNCTION_REF", "COMMON_FIELD_REF"


        :return: The value_data_type of this Attribute.
        :rtype: str
        """
        return self._value_data_type

    @value_data_type.setter
    def value_data_type(self, value_data_type):
        """
        Sets the value_data_type of this Attribute.
        value data type


        :param value_data_type: The value_data_type of this Attribute.
        :type: str
        """
        allowed_values = ["INTEGER", "LONG", "FLOAT", "STRING", "TIMESTAMP", "DATE", "CLOB", "TAG_REF", "PARSER_REF", "STT_REF", "LOOKUP_REF", "META_FUNCTION_REF", "COMMON_FIELD_REF"]
        if not value_allowed_none_or_none_sentinel(value_data_type, allowed_values):
            raise ValueError(
                "Invalid value for `value_data_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._value_data_type = value_data_type

    @property
    def value_population_priority(self):
        """
        Gets the value_population_priority of this Attribute.
        value population priority

        Allowed values for this property are: "NONE", "LOW", "HIGH"


        :return: The value_population_priority of this Attribute.
        :rtype: str
        """
        return self._value_population_priority

    @value_population_priority.setter
    def value_population_priority(self, value_population_priority):
        """
        Sets the value_population_priority of this Attribute.
        value population priority


        :param value_population_priority: The value_population_priority of this Attribute.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "HIGH"]
        if not value_allowed_none_or_none_sentinel(value_population_priority, allowed_values):
            raise ValueError(
                "Invalid value for `value_population_priority`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._value_population_priority = value_population_priority

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .file_storage_client import FileStorageClient
from .file_storage_client_composite_operations import FileStorageClientCompositeOperations
from . import models

__all__ = ["FileStorageClient", "FileStorageClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activity_problem_aggregation import ActivityProblemAggregation
from .activity_problem_aggregation_collection import ActivityProblemAggregationCollection
from .attach_target_detector_recipe_details import AttachTargetDetectorRecipeDetails
from .attach_target_responder_recipe_details import AttachTargetResponderRecipeDetails
from .candidate_responder_rule import CandidateResponderRule
from .change_detector_recipe_compartment_details import ChangeDetectorRecipeCompartmentDetails
from .change_managed_list_compartment_details import ChangeManagedListCompartmentDetails
from .change_responder_recipe_compartment_details import ChangeResponderRecipeCompartmentDetails
from .composite_condition import CompositeCondition
from .condition import Condition
from .condition_group import ConditionGroup
from .condition_metadata_type import ConditionMetadataType
from .condition_metadata_type_collection import ConditionMetadataTypeCollection
from .condition_metadata_type_summary import ConditionMetadataTypeSummary
from .condition_operator import ConditionOperator
from .config_value import ConfigValue
from .configuration import Configuration
from .create_detector_recipe_details import CreateDetectorRecipeDetails
from .create_managed_list_details import CreateManagedListDetails
from .create_responder_recipe_details import CreateResponderRecipeDetails
from .create_target_details import CreateTargetDetails
from .create_target_detector_recipe_details import CreateTargetDetectorRecipeDetails
from .create_target_responder_recipe_details import CreateTargetResponderRecipeDetails
from .detector import Detector
from .detector_collection import DetectorCollection
from .detector_configuration import DetectorConfiguration
from .detector_details import DetectorDetails
from .detector_recipe import DetectorRecipe
from .detector_recipe_collection import DetectorRecipeCollection
from .detector_recipe_detector_rule import DetectorRecipeDetectorRule
from .detector_recipe_detector_rule_collection import DetectorRecipeDetectorRuleCollection
from .detector_recipe_detector_rule_summary import DetectorRecipeDetectorRuleSummary
from .detector_recipe_summary import DetectorRecipeSummary
from .detector_rule import DetectorRule
from .detector_rule_collection import DetectorRuleCollection
from .detector_rule_summary import DetectorRuleSummary
from .detector_summary import DetectorSummary
from .execute_responder_execution_details import ExecuteResponderExecutionDetails
from .geographical_location import GeographicalLocation
from .impacted_resource_collection import ImpactedResourceCollection
from .impacted_resource_summary import ImpactedResourceSummary
from .managed_list import ManagedList
from .managed_list_collection import ManagedListCollection
from .managed_list_summary import ManagedListSummary
from .managed_list_type_collection import ManagedListTypeCollection
from .managed_list_type_summary import ManagedListTypeSummary
from .operator_summary import OperatorSummary
from .political_location import PoliticalLocation
from .problem import Problem
from .problem_aggregation import ProblemAggregation
from .problem_aggregation_collection import ProblemAggregationCollection
from .problem_collection import ProblemCollection
from .problem_history_collection import ProblemHistoryCollection
from .problem_history_summary import ProblemHistorySummary
from .problem_summary import ProblemSummary
from .problem_trend_aggregation import ProblemTrendAggregation
from .problem_trend_aggregation_collection import ProblemTrendAggregationCollection
from .recommendation_summary import RecommendationSummary
from .recommendation_summary_collection import RecommendationSummaryCollection
from .resource_type_collection import ResourceTypeCollection
from .resource_type_summary import ResourceTypeSummary
from .responder_activity_collection import ResponderActivityCollection
from .responder_activity_summary import ResponderActivitySummary
from .responder_configuration import ResponderConfiguration
from .responder_execution import ResponderExecution
from .responder_execution_aggregation import ResponderExecutionAggregation
from .responder_execution_aggregation_collection import ResponderExecutionAggregationCollection
from .responder_execution_collection import ResponderExecutionCollection
from .responder_execution_summary import ResponderExecutionSummary
from .responder_execution_trend_aggregation import ResponderExecutionTrendAggregation
from .responder_execution_trend_aggregation_collection import ResponderExecutionTrendAggregationCollection
from .responder_recipe import ResponderRecipe
from .responder_recipe_collection import ResponderRecipeCollection
from .responder_recipe_responder_rule import ResponderRecipeResponderRule
from .responder_recipe_responder_rule_collection import ResponderRecipeResponderRuleCollection
from .responder_recipe_responder_rule_summary import ResponderRecipeResponderRuleSummary
from .responder_recipe_summary import ResponderRecipeSummary
from .responder_rule import ResponderRule
from .responder_rule_collection import ResponderRuleCollection
from .responder_rule_details import ResponderRuleDetails
from .responder_rule_execution_details import ResponderRuleExecutionDetails
from .responder_rule_summary import ResponderRuleSummary
from .risk_score_aggregation import RiskScoreAggregation
from .risk_score_aggregation_collection import RiskScoreAggregationCollection
from .rule_summary import RuleSummary
from .security_score_aggregation import SecurityScoreAggregation
from .security_score_aggregation_collection import SecurityScoreAggregationCollection
from .security_score_trend_aggregation import SecurityScoreTrendAggregation
from .security_score_trend_aggregation_collection import SecurityScoreTrendAggregationCollection
from .service_type_summary import ServiceTypeSummary
from .simple_condition import SimpleCondition
from .skip_bulk_responder_execution_details import SkipBulkResponderExecutionDetails
from .target import Target
from .target_collection import TargetCollection
from .target_detector_details import TargetDetectorDetails
from .target_detector_recipe import TargetDetectorRecipe
from .target_detector_recipe_collection import TargetDetectorRecipeCollection
from .target_detector_recipe_detector_rule import TargetDetectorRecipeDetectorRule
from .target_detector_recipe_detector_rule_collection import TargetDetectorRecipeDetectorRuleCollection
from .target_detector_recipe_detector_rule_summary import TargetDetectorRecipeDetectorRuleSummary
from .target_detector_recipe_summary import TargetDetectorRecipeSummary
from .target_responder_recipe import TargetResponderRecipe
from .target_responder_recipe_collection import TargetResponderRecipeCollection
from .target_responder_recipe_responder_rule import TargetResponderRecipeResponderRule
from .target_responder_recipe_responder_rule_collection import TargetResponderRecipeResponderRuleCollection
from .target_responder_recipe_responder_rule_summary import TargetResponderRecipeResponderRuleSummary
from .target_responder_recipe_summary import TargetResponderRecipeSummary
from .target_summary import TargetSummary
from .trigger_responder_details import TriggerResponderDetails
from .update_bulk_problem_status_details import UpdateBulkProblemStatusDetails
from .update_configuration_details import UpdateConfigurationDetails
from .update_detector_recipe_details import UpdateDetectorRecipeDetails
from .update_detector_recipe_detector_rule import UpdateDetectorRecipeDetectorRule
from .update_detector_recipe_detector_rule_details import UpdateDetectorRecipeDetectorRuleDetails
from .update_detector_rule_details import UpdateDetectorRuleDetails
from .update_managed_list_details import UpdateManagedListDetails
from .update_problem_status_details import UpdateProblemStatusDetails
from .update_responder_recipe_details import UpdateResponderRecipeDetails
from .update_responder_recipe_responder_rule import UpdateResponderRecipeResponderRule
from .update_responder_recipe_responder_rule_details import UpdateResponderRecipeResponderRuleDetails
from .update_responder_rule_details import UpdateResponderRuleDetails
from .update_target_details import UpdateTargetDetails
from .update_target_detector_recipe import UpdateTargetDetectorRecipe
from .update_target_detector_recipe_details import UpdateTargetDetectorRecipeDetails
from .update_target_detector_recipe_detector_rule_details import UpdateTargetDetectorRecipeDetectorRuleDetails
from .update_target_detector_rule_details import UpdateTargetDetectorRuleDetails
from .update_target_recipe_detector_rule_details import UpdateTargetRecipeDetectorRuleDetails
from .update_target_recipe_responder_rule_details import UpdateTargetRecipeResponderRuleDetails
from .update_target_responder_recipe import UpdateTargetResponderRecipe
from .update_target_responder_recipe_details import UpdateTargetResponderRecipeDetails
from .update_target_responder_recipe_responder_rule_details import UpdateTargetResponderRecipeResponderRuleDetails
from .update_target_responder_rule_details import UpdateTargetResponderRuleDetails

# Maps type names to classes for cloud_guard services.
cloud_guard_type_mapping = {
    "ActivityProblemAggregation": ActivityProblemAggregation,
    "ActivityProblemAggregationCollection": ActivityProblemAggregationCollection,
    "AttachTargetDetectorRecipeDetails": AttachTargetDetectorRecipeDetails,
    "AttachTargetResponderRecipeDetails": AttachTargetResponderRecipeDetails,
    "CandidateResponderRule": CandidateResponderRule,
    "ChangeDetectorRecipeCompartmentDetails": ChangeDetectorRecipeCompartmentDetails,
    "ChangeManagedListCompartmentDetails": ChangeManagedListCompartmentDetails,
    "ChangeResponderRecipeCompartmentDetails": ChangeResponderRecipeCompartmentDetails,
    "CompositeCondition": CompositeCondition,
    "Condition": Condition,
    "ConditionGroup": ConditionGroup,
    "ConditionMetadataType": ConditionMetadataType,
    "ConditionMetadataTypeCollection": ConditionMetadataTypeCollection,
    "ConditionMetadataTypeSummary": ConditionMetadataTypeSummary,
    "ConditionOperator": ConditionOperator,
    "ConfigValue": ConfigValue,
    "Configuration": Configuration,
    "CreateDetectorRecipeDetails": CreateDetectorRecipeDetails,
    "CreateManagedListDetails": CreateManagedListDetails,
    "CreateResponderRecipeDetails": CreateResponderRecipeDetails,
    "CreateTargetDetails": CreateTargetDetails,
    "CreateTargetDetectorRecipeDetails": CreateTargetDetectorRecipeDetails,
    "CreateTargetResponderRecipeDetails": CreateTargetResponderRecipeDetails,
    "Detector": Detector,
    "DetectorCollection": DetectorCollection,
    "DetectorConfiguration": DetectorConfiguration,
    "DetectorDetails": DetectorDetails,
    "DetectorRecipe": DetectorRecipe,
    "DetectorRecipeCollection": DetectorRecipeCollection,
    "DetectorRecipeDetectorRule": DetectorRecipeDetectorRule,
    "DetectorRecipeDetectorRuleCollection": DetectorRecipeDetectorRuleCollection,
    "DetectorRecipeDetectorRuleSummary": DetectorRecipeDetectorRuleSummary,
    "DetectorRecipeSummary": DetectorRecipeSummary,
    "DetectorRule": DetectorRule,
    "DetectorRuleCollection": DetectorRuleCollection,
    "DetectorRuleSummary": DetectorRuleSummary,
    "DetectorSummary": DetectorSummary,
    "ExecuteResponderExecutionDetails": ExecuteResponderExecutionDetails,
    "GeographicalLocation": GeographicalLocation,
    "ImpactedResourceCollection": ImpactedResourceCollection,
    "ImpactedResourceSummary": ImpactedResourceSummary,
    "ManagedList": ManagedList,
    "ManagedListCollection": ManagedListCollection,
    "ManagedListSummary": ManagedListSummary,
    "ManagedListTypeCollection": ManagedListTypeCollection,
    "ManagedListTypeSummary": ManagedListTypeSummary,
    "OperatorSummary": OperatorSummary,
    "PoliticalLocation": PoliticalLocation,
    "Problem": Problem,
    "ProblemAggregation": ProblemAggregation,
    "ProblemAggregationCollection": ProblemAggregationCollection,
    "ProblemCollection": ProblemCollection,
    "ProblemHistoryCollection": ProblemHistoryCollection,
    "ProblemHistorySummary": ProblemHistorySummary,
    "ProblemSummary": ProblemSummary,
    "ProblemTrendAggregation": ProblemTrendAggregation,
    "ProblemTrendAggregationCollection": ProblemTrendAggregationCollection,
    "RecommendationSummary": RecommendationSummary,
    "RecommendationSummaryCollection": RecommendationSummaryCollection,
    "ResourceTypeCollection": ResourceTypeCollection,
    "ResourceTypeSummary": ResourceTypeSummary,
    "ResponderActivityCollection": ResponderActivityCollection,
    "ResponderActivitySummary": ResponderActivitySummary,
    "ResponderConfiguration": ResponderConfiguration,
    "ResponderExecution": ResponderExecution,
    "ResponderExecutionAggregation": ResponderExecutionAggregation,
    "ResponderExecutionAggregationCollection": ResponderExecutionAggregationCollection,
    "ResponderExecutionCollection": ResponderExecutionCollection,
    "ResponderExecutionSummary": ResponderExecutionSummary,
    "ResponderExecutionTrendAggregation": ResponderExecutionTrendAggregation,
    "ResponderExecutionTrendAggregationCollection": ResponderExecutionTrendAggregationCollection,
    "ResponderRecipe": ResponderRecipe,
    "ResponderRecipeCollection": ResponderRecipeCollection,
    "ResponderRecipeResponderRule": ResponderRecipeResponderRule,
    "ResponderRecipeResponderRuleCollection": ResponderRecipeResponderRuleCollection,
    "ResponderRecipeResponderRuleSummary": ResponderRecipeResponderRuleSummary,
    "ResponderRecipeSummary": ResponderRecipeSummary,
    "ResponderRule": ResponderRule,
    "ResponderRuleCollection": ResponderRuleCollection,
    "ResponderRuleDetails": ResponderRuleDetails,
    "ResponderRuleExecutionDetails": ResponderRuleExecutionDetails,
    "ResponderRuleSummary": ResponderRuleSummary,
    "RiskScoreAggregation": RiskScoreAggregation,
    "RiskScoreAggregationCollection": RiskScoreAggregationCollection,
    "RuleSummary": RuleSummary,
    "SecurityScoreAggregation": SecurityScoreAggregation,
    "SecurityScoreAggregationCollection": SecurityScoreAggregationCollection,
    "SecurityScoreTrendAggregation": SecurityScoreTrendAggregation,
    "SecurityScoreTrendAggregationCollection": SecurityScoreTrendAggregationCollection,
    "ServiceTypeSummary": ServiceTypeSummary,
    "SimpleCondition": SimpleCondition,
    "SkipBulkResponderExecutionDetails": SkipBulkResponderExecutionDetails,
    "Target": Target,
    "TargetCollection": TargetCollection,
    "TargetDetectorDetails": TargetDetectorDetails,
    "TargetDetectorRecipe": TargetDetectorRecipe,
    "TargetDetectorRecipeCollection": TargetDetectorRecipeCollection,
    "TargetDetectorRecipeDetectorRule": TargetDetectorRecipeDetectorRule,
    "TargetDetectorRecipeDetectorRuleCollection": TargetDetectorRecipeDetectorRuleCollection,
    "TargetDetectorRecipeDetectorRuleSummary": TargetDetectorRecipeDetectorRuleSummary,
    "TargetDetectorRecipeSummary": TargetDetectorRecipeSummary,
    "TargetResponderRecipe": TargetResponderRecipe,
    "TargetResponderRecipeCollection": TargetResponderRecipeCollection,
    "TargetResponderRecipeResponderRule": TargetResponderRecipeResponderRule,
    "TargetResponderRecipeResponderRuleCollection": TargetResponderRecipeResponderRuleCollection,
    "TargetResponderRecipeResponderRuleSummary": TargetResponderRecipeResponderRuleSummary,
    "TargetResponderRecipeSummary": TargetResponderRecipeSummary,
    "TargetSummary": TargetSummary,
    "TriggerResponderDetails": TriggerResponderDetails,
    "UpdateBulkProblemStatusDetails": UpdateBulkProblemStatusDetails,
    "UpdateConfigurationDetails": UpdateConfigurationDetails,
    "UpdateDetectorRecipeDetails": UpdateDetectorRecipeDetails,
    "UpdateDetectorRecipeDetectorRule": UpdateDetectorRecipeDetectorRule,
    "UpdateDetectorRecipeDetectorRuleDetails": UpdateDetectorRecipeDetectorRuleDetails,
    "UpdateDetectorRuleDetails": UpdateDetectorRuleDetails,
    "UpdateManagedListDetails": UpdateManagedListDetails,
    "UpdateProblemStatusDetails": UpdateProblemStatusDetails,
    "UpdateResponderRecipeDetails": UpdateResponderRecipeDetails,
    "UpdateResponderRecipeResponderRule": UpdateResponderRecipeResponderRule,
    "UpdateResponderRecipeResponderRuleDetails": UpdateResponderRecipeResponderRuleDetails,
    "UpdateResponderRuleDetails": UpdateResponderRuleDetails,
    "UpdateTargetDetails": UpdateTargetDetails,
    "UpdateTargetDetectorRecipe": UpdateTargetDetectorRecipe,
    "UpdateTargetDetectorRecipeDetails": UpdateTargetDetectorRecipeDetails,
    "UpdateTargetDetectorRecipeDetectorRuleDetails": UpdateTargetDetectorRecipeDetectorRuleDetails,
    "UpdateTargetDetectorRuleDetails": UpdateTargetDetectorRuleDetails,
    "UpdateTargetRecipeDetectorRuleDetails": UpdateTargetRecipeDetectorRuleDetails,
    "UpdateTargetRecipeResponderRuleDetails": UpdateTargetRecipeResponderRuleDetails,
    "UpdateTargetResponderRecipe": UpdateTargetResponderRecipe,
    "UpdateTargetResponderRecipeDetails": UpdateTargetResponderRecipeDetails,
    "UpdateTargetResponderRecipeResponderRuleDetails": UpdateTargetResponderRecipeResponderRuleDetails,
    "UpdateTargetResponderRuleDetails": UpdateTargetResponderRuleDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SoftwarePackageSearchSummary(object):
    """
    Summary information for a software package
    """

    #: A constant which can be used with the advisory_type property of a SoftwarePackageSearchSummary.
    #: This constant has a value of "SECURITY"
    ADVISORY_TYPE_SECURITY = "SECURITY"

    #: A constant which can be used with the advisory_type property of a SoftwarePackageSearchSummary.
    #: This constant has a value of "BUG"
    ADVISORY_TYPE_BUG = "BUG"

    #: A constant which can be used with the advisory_type property of a SoftwarePackageSearchSummary.
    #: This constant has a value of "ENHANCEMENT"
    ADVISORY_TYPE_ENHANCEMENT = "ENHANCEMENT"

    #: A constant which can be used with the advisory_type property of a SoftwarePackageSearchSummary.
    #: This constant has a value of "OTHER"
    ADVISORY_TYPE_OTHER = "OTHER"

    def __init__(self, **kwargs):
        """
        Initializes a new SoftwarePackageSearchSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this SoftwarePackageSearchSummary.
        :type display_name: str

        :param name:
            The value to assign to the name property of this SoftwarePackageSearchSummary.
        :type name: str

        :param type:
            The value to assign to the type property of this SoftwarePackageSearchSummary.
        :type type: str

        :param version:
            The value to assign to the version property of this SoftwarePackageSearchSummary.
        :type version: str

        :param architecture:
            The value to assign to the architecture property of this SoftwarePackageSearchSummary.
        :type architecture: str

        :param summary:
            The value to assign to the summary property of this SoftwarePackageSearchSummary.
        :type summary: str

        :param advisory_type:
            The value to assign to the advisory_type property of this SoftwarePackageSearchSummary.
            Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type advisory_type: str

        :param errata:
            The value to assign to the errata property of this SoftwarePackageSearchSummary.
        :type errata: list[Id]

        :param software_sources:
            The value to assign to the software_sources property of this SoftwarePackageSearchSummary.
        :type software_sources: list[SoftwareSourceId]

        """
        self.swagger_types = {
            'display_name': 'str',
            'name': 'str',
            'type': 'str',
            'version': 'str',
            'architecture': 'str',
            'summary': 'str',
            'advisory_type': 'str',
            'errata': 'list[Id]',
            'software_sources': 'list[SoftwareSourceId]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'name': 'name',
            'type': 'type',
            'version': 'version',
            'architecture': 'architecture',
            'summary': 'summary',
            'advisory_type': 'advisoryType',
            'errata': 'errata',
            'software_sources': 'softwareSources'
        }

        self._display_name = None
        self._name = None
        self._type = None
        self._version = None
        self._architecture = None
        self._summary = None
        self._advisory_type = None
        self._errata = None
        self._software_sources = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SoftwarePackageSearchSummary.
        Package name


        :return: The display_name of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SoftwarePackageSearchSummary.
        Package name


        :param display_name: The display_name of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def name(self):
        """
        **[Required]** Gets the name of this SoftwarePackageSearchSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :return: The name of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SoftwarePackageSearchSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :param name: The name of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this SoftwarePackageSearchSummary.
        Type of the package


        :return: The type of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SoftwarePackageSearchSummary.
        Type of the package


        :param type: The type of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._type = type

    @property
    def version(self):
        """
        **[Required]** Gets the version of this SoftwarePackageSearchSummary.
        Version of the package


        :return: The version of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SoftwarePackageSearchSummary.
        Version of the package


        :param version: The version of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._version = version

    @property
    def architecture(self):
        """
        Gets the architecture of this SoftwarePackageSearchSummary.
        the architecture for which this software was built


        :return: The architecture of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture):
        """
        Sets the architecture of this SoftwarePackageSearchSummary.
        the architecture for which this software was built


        :param architecture: The architecture of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._architecture = architecture

    @property
    def summary(self):
        """
        Gets the summary of this SoftwarePackageSearchSummary.
        a summary description of the software package


        :return: The summary of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this SoftwarePackageSearchSummary.
        a summary description of the software package


        :param summary: The summary of this SoftwarePackageSearchSummary.
        :type: str
        """
        self._summary = summary

    @property
    def advisory_type(self):
        """
        Gets the advisory_type of this SoftwarePackageSearchSummary.
        Type of the erratum.

        Allowed values for this property are: "SECURITY", "BUG", "ENHANCEMENT", "OTHER", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The advisory_type of this SoftwarePackageSearchSummary.
        :rtype: str
        """
        return self._advisory_type

    @advisory_type.setter
    def advisory_type(self, advisory_type):
        """
        Sets the advisory_type of this SoftwarePackageSearchSummary.
        Type of the erratum.


        :param advisory_type: The advisory_type of this SoftwarePackageSearchSummary.
        :type: str
        """
        allowed_values = ["SECURITY", "BUG", "ENHANCEMENT", "OTHER"]
        if not value_allowed_none_or_none_sentinel(advisory_type, allowed_values):
            advisory_type = 'UNKNOWN_ENUM_VALUE'
        self._advisory_type = advisory_type

    @property
    def errata(self):
        """
        Gets the errata of this SoftwarePackageSearchSummary.
        List of errata containing this software package


        :return: The errata of this SoftwarePackageSearchSummary.
        :rtype: list[Id]
        """
        return self._errata

    @errata.setter
    def errata(self, errata):
        """
        Sets the errata of this SoftwarePackageSearchSummary.
        List of errata containing this software package


        :param errata: The errata of this SoftwarePackageSearchSummary.
        :type: list[Id]
        """
        self._errata = errata

    @property
    def software_sources(self):
        """
        Gets the software_sources of this SoftwarePackageSearchSummary.
        list of software sources that provide the software package


        :return: The software_sources of this SoftwarePackageSearchSummary.
        :rtype: list[SoftwareSourceId]
        """
        return self._software_sources

    @software_sources.setter
    def software_sources(self, software_sources):
        """
        Sets the software_sources of this SoftwarePackageSearchSummary.
        list of software sources that provide the software package


        :param software_sources: The software_sources of this SoftwarePackageSearchSummary.
        :type: list[SoftwareSourceId]
        """
        self._software_sources = software_sources

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TransferDevice(object):
    """
    TransferDevice model.
    """

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "PREPARING"
    LIFECYCLE_STATE_PREPARING = "PREPARING"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "READY"
    LIFECYCLE_STATE_READY = "READY"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "PACKAGED"
    LIFECYCLE_STATE_PACKAGED = "PACKAGED"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "PROCESSING"
    LIFECYCLE_STATE_PROCESSING = "PROCESSING"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "COMPLETE"
    LIFECYCLE_STATE_COMPLETE = "COMPLETE"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "MISSING"
    LIFECYCLE_STATE_MISSING = "MISSING"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "ERROR"
    LIFECYCLE_STATE_ERROR = "ERROR"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a TransferDevice.
    #: This constant has a value of "CANCELLED"
    LIFECYCLE_STATE_CANCELLED = "CANCELLED"

    def __init__(self, **kwargs):
        """
        Initializes a new TransferDevice object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param serial_number:
            The value to assign to the serial_number property of this TransferDevice.
        :type serial_number: str

        :param iscsi_iqn:
            The value to assign to the iscsi_iqn property of this TransferDevice.
        :type iscsi_iqn: str

        :param label:
            The value to assign to the label property of this TransferDevice.
        :type label: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TransferDevice.
            Allowed values for this property are: "PREPARING", "READY", "PACKAGED", "ACTIVE", "PROCESSING", "COMPLETE", "MISSING", "ERROR", "DELETED", "CANCELLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param transfer_job_id:
            The value to assign to the transfer_job_id property of this TransferDevice.
        :type transfer_job_id: str

        :param attached_transfer_package_label:
            The value to assign to the attached_transfer_package_label property of this TransferDevice.
        :type attached_transfer_package_label: str

        :param creation_time:
            The value to assign to the creation_time property of this TransferDevice.
        :type creation_time: datetime

        :param upload_status_log_uri:
            The value to assign to the upload_status_log_uri property of this TransferDevice.
        :type upload_status_log_uri: str

        """
        self.swagger_types = {
            'serial_number': 'str',
            'iscsi_iqn': 'str',
            'label': 'str',
            'lifecycle_state': 'str',
            'transfer_job_id': 'str',
            'attached_transfer_package_label': 'str',
            'creation_time': 'datetime',
            'upload_status_log_uri': 'str'
        }

        self.attribute_map = {
            'serial_number': 'serialNumber',
            'iscsi_iqn': 'iscsiIQN',
            'label': 'label',
            'lifecycle_state': 'lifecycleState',
            'transfer_job_id': 'transferJobId',
            'attached_transfer_package_label': 'attachedTransferPackageLabel',
            'creation_time': 'creationTime',
            'upload_status_log_uri': 'uploadStatusLogUri'
        }

        self._serial_number = None
        self._iscsi_iqn = None
        self._label = None
        self._lifecycle_state = None
        self._transfer_job_id = None
        self._attached_transfer_package_label = None
        self._creation_time = None
        self._upload_status_log_uri = None

    @property
    def serial_number(self):
        """
        Gets the serial_number of this TransferDevice.

        :return: The serial_number of this TransferDevice.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this TransferDevice.

        :param serial_number: The serial_number of this TransferDevice.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def iscsi_iqn(self):
        """
        Gets the iscsi_iqn of this TransferDevice.

        :return: The iscsi_iqn of this TransferDevice.
        :rtype: str
        """
        return self._iscsi_iqn

    @iscsi_iqn.setter
    def iscsi_iqn(self, iscsi_iqn):
        """
        Sets the iscsi_iqn of this TransferDevice.

        :param iscsi_iqn: The iscsi_iqn of this TransferDevice.
        :type: str
        """
        self._iscsi_iqn = iscsi_iqn

    @property
    def label(self):
        """
        **[Required]** Gets the label of this TransferDevice.

        :return: The label of this TransferDevice.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this TransferDevice.

        :param label: The label of this TransferDevice.
        :type: str
        """
        self._label = label

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TransferDevice.
        Allowed values for this property are: "PREPARING", "READY", "PACKAGED", "ACTIVE", "PROCESSING", "COMPLETE", "MISSING", "ERROR", "DELETED", "CANCELLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TransferDevice.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TransferDevice.

        :param lifecycle_state: The lifecycle_state of this TransferDevice.
        :type: str
        """
        allowed_values = ["PREPARING", "READY", "PACKAGED", "ACTIVE", "PROCESSING", "COMPLETE", "MISSING", "ERROR", "DELETED", "CANCELLED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def transfer_job_id(self):
        """
        Gets the transfer_job_id of this TransferDevice.

        :return: The transfer_job_id of this TransferDevice.
        :rtype: str
        """
        return self._transfer_job_id

    @transfer_job_id.setter
    def transfer_job_id(self, transfer_job_id):
        """
        Sets the transfer_job_id of this TransferDevice.

        :param transfer_job_id: The transfer_job_id of this TransferDevice.
        :type: str
        """
        self._transfer_job_id = transfer_job_id

    @property
    def attached_transfer_package_label(self):
        """
        Gets the attached_transfer_package_label of this TransferDevice.

        :return: The attached_transfer_package_label of this TransferDevice.
        :rtype: str
        """
        return self._attached_transfer_package_label

    @attached_transfer_package_label.setter
    def attached_transfer_package_label(self, attached_transfer_package_label):
        """
        Sets the attached_transfer_package_label of this TransferDevice.

        :param attached_transfer_package_label: The attached_transfer_package_label of this TransferDevice.
        :type: str
        """
        self._attached_transfer_package_label = attached_transfer_package_label

    @property
    def creation_time(self):
        """
        Gets the creation_time of this TransferDevice.

        :return: The creation_time of this TransferDevice.
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """
        Sets the creation_time of this TransferDevice.

        :param creation_time: The creation_time of this TransferDevice.
        :type: datetime
        """
        self._creation_time = creation_time

    @property
    def upload_status_log_uri(self):
        """
        Gets the upload_status_log_uri of this TransferDevice.

        :return: The upload_status_log_uri of this TransferDevice.
        :rtype: str
        """
        return self._upload_status_log_uri

    @upload_status_log_uri.setter
    def upload_status_log_uri(self, upload_status_log_uri):
        """
        Sets the upload_status_log_uri of this TransferDevice.

        :param upload_status_log_uri: The upload_status_log_uri of this TransferDevice.
        :type: str
        """
        self._upload_status_log_uri = upload_status_log_uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ScanDetails(object):
    """
    The Single Client Access Name (SCAN) details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ScanDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hostname:
            The value to assign to the hostname property of this ScanDetails.
        :type hostname: str

        :param port:
            The value to assign to the port property of this ScanDetails.
        :type port: int

        :param ips:
            The value to assign to the ips property of this ScanDetails.
        :type ips: list[str]

        """
        self.swagger_types = {
            'hostname': 'str',
            'port': 'int',
            'ips': 'list[str]'
        }

        self.attribute_map = {
            'hostname': 'hostname',
            'port': 'port',
            'ips': 'ips'
        }

        self._hostname = None
        self._port = None
        self._ips = None

    @property
    def hostname(self):
        """
        **[Required]** Gets the hostname of this ScanDetails.
        The SCAN hostname.


        :return: The hostname of this ScanDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this ScanDetails.
        The SCAN hostname.


        :param hostname: The hostname of this ScanDetails.
        :type: str
        """
        self._hostname = hostname

    @property
    def port(self):
        """
        **[Required]** Gets the port of this ScanDetails.
        The SCAN port. Default is 1521.


        :return: The port of this ScanDetails.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this ScanDetails.
        The SCAN port. Default is 1521.


        :param port: The port of this ScanDetails.
        :type: int
        """
        self._port = port

    @property
    def ips(self):
        """
        **[Required]** Gets the ips of this ScanDetails.
        The list of SCAN IP addresses. Three addresses should be provided.


        :return: The ips of this ScanDetails.
        :rtype: list[str]
        """
        return self._ips

    @ips.setter
    def ips(self, ips):
        """
        Sets the ips of this ScanDetails.
        The list of SCAN IP addresses. Three addresses should be provided.


        :param ips: The ips of this ScanDetails.
        :type: list[str]
        """
        self._ips = ips

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateSubjectName(object):
    """
    The entity to be secured by the certificate.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateSubjectName object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param country:
            The value to assign to the country property of this CertificateSubjectName.
        :type country: str

        :param state_province:
            The value to assign to the state_province property of this CertificateSubjectName.
        :type state_province: str

        :param locality:
            The value to assign to the locality property of this CertificateSubjectName.
        :type locality: str

        :param organization:
            The value to assign to the organization property of this CertificateSubjectName.
        :type organization: str

        :param organizational_unit:
            The value to assign to the organizational_unit property of this CertificateSubjectName.
        :type organizational_unit: str

        :param common_name:
            The value to assign to the common_name property of this CertificateSubjectName.
        :type common_name: str

        :param email_address:
            The value to assign to the email_address property of this CertificateSubjectName.
        :type email_address: str

        """
        self.swagger_types = {
            'country': 'str',
            'state_province': 'str',
            'locality': 'str',
            'organization': 'str',
            'organizational_unit': 'str',
            'common_name': 'str',
            'email_address': 'str'
        }

        self.attribute_map = {
            'country': 'country',
            'state_province': 'stateProvince',
            'locality': 'locality',
            'organization': 'organization',
            'organizational_unit': 'organizationalUnit',
            'common_name': 'commonName',
            'email_address': 'emailAddress'
        }

        self._country = None
        self._state_province = None
        self._locality = None
        self._organization = None
        self._organizational_unit = None
        self._common_name = None
        self._email_address = None

    @property
    def country(self):
        """
        Gets the country of this CertificateSubjectName.
        ISO 3166-1 alpha-2 code of the country where the organization is located. For a list of codes, see `ISO's website`__.

        __ https://www.iso.org/obp/ui/#search/code/


        :return: The country of this CertificateSubjectName.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this CertificateSubjectName.
        ISO 3166-1 alpha-2 code of the country where the organization is located. For a list of codes, see `ISO's website`__.

        __ https://www.iso.org/obp/ui/#search/code/


        :param country: The country of this CertificateSubjectName.
        :type: str
        """
        self._country = country

    @property
    def state_province(self):
        """
        Gets the state_province of this CertificateSubjectName.
        The province where the organization is located.


        :return: The state_province of this CertificateSubjectName.
        :rtype: str
        """
        return self._state_province

    @state_province.setter
    def state_province(self, state_province):
        """
        Sets the state_province of this CertificateSubjectName.
        The province where the organization is located.


        :param state_province: The state_province of this CertificateSubjectName.
        :type: str
        """
        self._state_province = state_province

    @property
    def locality(self):
        """
        Gets the locality of this CertificateSubjectName.
        The city in which the organization is located.


        :return: The locality of this CertificateSubjectName.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this CertificateSubjectName.
        The city in which the organization is located.


        :param locality: The locality of this CertificateSubjectName.
        :type: str
        """
        self._locality = locality

    @property
    def organization(self):
        """
        Gets the organization of this CertificateSubjectName.
        The organization name.


        :return: The organization of this CertificateSubjectName.
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this CertificateSubjectName.
        The organization name.


        :param organization: The organization of this CertificateSubjectName.
        :type: str
        """
        self._organization = organization

    @property
    def organizational_unit(self):
        """
        Gets the organizational_unit of this CertificateSubjectName.
        The field to differentiate between divisions within an organization.


        :return: The organizational_unit of this CertificateSubjectName.
        :rtype: str
        """
        return self._organizational_unit

    @organizational_unit.setter
    def organizational_unit(self, organizational_unit):
        """
        Sets the organizational_unit of this CertificateSubjectName.
        The field to differentiate between divisions within an organization.


        :param organizational_unit: The organizational_unit of this CertificateSubjectName.
        :type: str
        """
        self._organizational_unit = organizational_unit

    @property
    def common_name(self):
        """
        Gets the common_name of this CertificateSubjectName.
        The fully qualified domain name used for DNS lookups of the server.


        :return: The common_name of this CertificateSubjectName.
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """
        Sets the common_name of this CertificateSubjectName.
        The fully qualified domain name used for DNS lookups of the server.


        :param common_name: The common_name of this CertificateSubjectName.
        :type: str
        """
        self._common_name = common_name

    @property
    def email_address(self):
        """
        Gets the email_address of this CertificateSubjectName.
        The email address of the server's administrator.


        :return: The email_address of this CertificateSubjectName.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """
        Sets the email_address of this CertificateSubjectName.
        The email address of the server's administrator.


        :param email_address: The email_address of this CertificateSubjectName.
        :type: str
        """
        self._email_address = email_address

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthenticationPolicy(object):
    """
    Authentication policy, currently set for the given compartment
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AuthenticationPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param password_policy:
            The value to assign to the password_policy property of this AuthenticationPolicy.
        :type password_policy: PasswordPolicy

        :param compartment_id:
            The value to assign to the compartment_id property of this AuthenticationPolicy.
        :type compartment_id: str

        :param network_policy:
            The value to assign to the network_policy property of this AuthenticationPolicy.
        :type network_policy: NetworkPolicy

        """
        self.swagger_types = {
            'password_policy': 'PasswordPolicy',
            'compartment_id': 'str',
            'network_policy': 'NetworkPolicy'
        }

        self.attribute_map = {
            'password_policy': 'passwordPolicy',
            'compartment_id': 'compartmentId',
            'network_policy': 'networkPolicy'
        }

        self._password_policy = None
        self._compartment_id = None
        self._network_policy = None

    @property
    def password_policy(self):
        """
        Gets the password_policy of this AuthenticationPolicy.

        :return: The password_policy of this AuthenticationPolicy.
        :rtype: PasswordPolicy
        """
        return self._password_policy

    @password_policy.setter
    def password_policy(self, password_policy):
        """
        Sets the password_policy of this AuthenticationPolicy.

        :param password_policy: The password_policy of this AuthenticationPolicy.
        :type: PasswordPolicy
        """
        self._password_policy = password_policy

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this AuthenticationPolicy.
        Compartment OCID.


        :return: The compartment_id of this AuthenticationPolicy.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AuthenticationPolicy.
        Compartment OCID.


        :param compartment_id: The compartment_id of this AuthenticationPolicy.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def network_policy(self):
        """
        Gets the network_policy of this AuthenticationPolicy.

        :return: The network_policy of this AuthenticationPolicy.
        :rtype: NetworkPolicy
        """
        return self._network_policy

    @network_policy.setter
    def network_policy(self, network_policy):
        """
        Sets the network_policy of this AuthenticationPolicy.

        :param network_policy: The network_policy of this AuthenticationPolicy.
        :type: NetworkPolicy
        """
        self._network_policy = network_policy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2018, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Original Work: Copyright (c) 2018 Character Encoding Detector contributors.  https://github.com/chardet

from .charsetprober import CharSetProber
from .enums import ProbingState

# This prober doesn't actually recognize a language or a charset.
# It is a helper prober for the use of the Hebrew model probers

### General ideas of the Hebrew charset recognition ###
#
# Four main charsets exist in Hebrew:
# "ISO-8859-8" - Visual Hebrew
# "windows-1255" - Logical Hebrew
# "ISO-8859-8-I" - Logical Hebrew
# "x-mac-hebrew" - ?? Logical Hebrew ??
#
# Both "ISO" charsets use a completely identical set of code points, whereas
# "windows-1255" and "x-mac-hebrew" are two different proper supersets of
# these code points. windows-1255 defines additional characters in the range
# 0x80-0x9F as some misc punctuation marks as well as some Hebrew-specific
# diacritics and additional 'Yiddish' ligature letters in the range 0xc0-0xd6.
# x-mac-hebrew defines similar additional code points but with a different
# mapping.
#
# As far as an average Hebrew text with no diacritics is concerned, all four
# charsets are identical with respect to code points. Meaning that for the
# main Hebrew alphabet, all four map the same values to all 27 Hebrew letters
# (including final letters).
#
# The dominant difference between these charsets is their directionality.
# "Visual" directionality means that the text is ordered as if the renderer is
# not aware of a BIDI rendering algorithm. The renderer sees the text and
# draws it from left to right. The text itself when ordered naturally is read
# backwards. A buffer of Visual Hebrew generally looks like so:
# "[last word of first line spelled backwards] [whole line ordered backwards
# and spelled backwards] [first word of first line spelled backwards]
# [end of line] [last word of second line] ... etc' "
# adding punctuation marks, numbers and English text to visual text is
# naturally also "visual" and from left to right.
#
# "Logical" directionality means the text is ordered "naturally" according to
# the order it is read. It is the responsibility of the renderer to display
# the text from right to left. A BIDI algorithm is used to place general
# punctuation marks, numbers and English text in the text.
#
# Texts in x-mac-hebrew are almost impossible to find on the Internet. From
# what little evidence I could find, it seems that its general directionality
# is Logical.
#
# To sum up all of the above, the Hebrew probing mechanism knows about two
# charsets:
# Visual Hebrew - "ISO-8859-8" - backwards text - Words and sentences are
#    backwards while line order is natural. For charset recognition purposes
#    the line order is unimportant (In fact, for this implementation, even
#    word order is unimportant).
# Logical Hebrew - "windows-1255" - normal, naturally ordered text.
#
# "ISO-8859-8-I" is a subset of windows-1255 and doesn't need to be
#    specifically identified.
# "x-mac-hebrew" is also identified as windows-1255. A text in x-mac-hebrew
#    that contain special punctuation marks or diacritics is displayed with
#    some unconverted characters showing as question marks. This problem might
#    be corrected using another model prober for x-mac-hebrew. Due to the fact
#    that x-mac-hebrew texts are so rare, writing another model prober isn't
#    worth the effort and performance hit.
#
#### The Prober ####
#
# The prober is divided between two SBCharSetProbers and a HebrewProber,
# all of which are managed, created, fed data, inquired and deleted by the
# SBCSGroupProber. The two SBCharSetProbers identify that the text is in
# fact some kind of Hebrew, Logical or Visual. The final decision about which
# one is it is made by the HebrewProber by combining final-letter scores
# with the scores of the two SBCharSetProbers to produce a final answer.
#
# The SBCSGroupProber is responsible for stripping the original text of HTML
# tags, English characters, numbers, low-ASCII punctuation characters, spaces
# and new lines. It reduces any sequence of such characters to a single space.
# The buffer fed to each prober in the SBCS group prober is pure text in
# high-ASCII.
# The two SBCharSetProbers (model probers) share the same language model:
# Win1255Model.
# The first SBCharSetProber uses the model normally as any other
# SBCharSetProber does, to recognize windows-1255, upon which this model was
# built. The second SBCharSetProber is told to make the pair-of-letter
# lookup in the language model backwards. This in practice exactly simulates
# a visual Hebrew model using the windows-1255 logical Hebrew model.
#
# The HebrewProber is not using any language model. All it does is look for
# final-letter evidence suggesting the text is either logical Hebrew or visual
# Hebrew. Disjointed from the model probers, the results of the HebrewProber
# alone are meaningless. HebrewProber always returns 0.00 as confidence
# since it never identifies a charset by itself. Instead, the pointer to the
# HebrewProber is passed to the model probers as a helper "Name Prober".
# When the Group prober receives a positive identification from any prober,
# it asks for the name of the charset identified. If the prober queried is a
# Hebrew model prober, the model prober forwards the call to the
# HebrewProber to make the final decision. In the HebrewProber, the
# decision is made according to the final-letters scores maintained and Both
# model probers scores. The answer is returned in the form of the name of the
# charset identified, either "windows-1255" or "ISO-8859-8".

class HebrewProber(CharSetProber):
    # windows-1255 / ISO-8859-8 code points of interest
    FINAL_KAF = 0xea
    NORMAL_KAF = 0xeb
    FINAL_MEM = 0xed
    NORMAL_MEM = 0xee
    FINAL_NUN = 0xef
    NORMAL_NUN = 0xf0
    FINAL_PE = 0xf3
    NORMAL_PE = 0xf4
    FINAL_TSADI = 0xf5
    NORMAL_TSADI = 0xf6

    # Minimum Visual vs Logical final letter score difference.
    # If the difference is below this, don't rely solely on the final letter score
    # distance.
    MIN_FINAL_CHAR_DISTANCE = 5

    # Minimum Visual vs Logical model score difference.
    # If the difference is below this, don't rely at all on the model score
    # distance.
    MIN_MODEL_DISTANCE = 0.01

    VISUAL_HEBREW_NAME = "ISO-8859-8"
    LOGICAL_HEBREW_NAME = "windows-1255"

    def __init__(self):
        super(HebrewProber, self).__init__()
        self._final_char_logical_score = None
        self._final_char_visual_score = None
        self._prev = None
        self._before_prev = None
        self._logical_prober = None
        self._visual_prober = None
        self.reset()

    def reset(self):
        self._final_char_logical_score = 0
        self._final_char_visual_score = 0
        # The two last characters seen in the previous buffer,
        # mPrev and mBeforePrev are initialized to space in order to simulate
        # a word delimiter at the beginning of the data
        self._prev = ' '
        self._before_prev = ' '
        # These probers are owned by the group prober.

    def set_model_probers(self, logicalProber, visualProber):
        self._logical_prober = logicalProber
        self._visual_prober = visualProber

    def is_final(self, c):
        return c in [self.FINAL_KAF, self.FINAL_MEM, self.FINAL_NUN,
                     self.FINAL_PE, self.FINAL_TSADI]

    def is_non_final(self, c):
        # The normal Tsadi is not a good Non-Final letter due to words like
        # 'lechotet' (to chat) containing an apostrophe after the tsadi. This
        # apostrophe is converted to a space in FilterWithoutEnglishLetters
        # causing the Non-Final tsadi to appear at an end of a word even
        # though this is not the case in the original text.
        # The letters Pe and Kaf rarely display a related behavior of not being
        # a good Non-Final letter. Words like 'Pop', 'Winamp' and 'Mubarak'
        # for example legally end with a Non-Final Pe or Kaf. However, the
        # benefit of these letters as Non-Final letters outweighs the damage
        # since these words are quite rare.
        return c in [self.NORMAL_KAF, self.NORMAL_MEM,
                     self.NORMAL_NUN, self.NORMAL_PE]

    def feed(self, byte_str):
        # Final letter analysis for logical-visual decision.
        # Look for evidence that the received buffer is either logical Hebrew
        # or visual Hebrew.
        # The following cases are checked:
        # 1) A word longer than 1 letter, ending with a final letter. This is
        #    an indication that the text is laid out "naturally" since the
        #    final letter really appears at the end. +1 for logical score.
        # 2) A word longer than 1 letter, ending with a Non-Final letter. In
        #    normal Hebrew, words ending with Kaf, Mem, Nun, Pe or Tsadi,
        #    should not end with the Non-Final form of that letter. Exceptions
        #    to this rule are mentioned above in isNonFinal(). This is an
        #    indication that the text is laid out backwards. +1 for visual
        #    score
        # 3) A word longer than 1 letter, starting with a final letter. Final
        #    letters should not appear at the beginning of a word. This is an
        #    indication that the text is laid out backwards. +1 for visual
        #    score.
        #
        # The visual score and logical score are accumulated throughout the
        # text and are finally checked against each other in GetCharSetName().
        # No checking for final letters in the middle of words is done since
        # that case is not an indication for either Logical or Visual text.
        #
        # We automatically filter out all 7-bit characters (replace them with
        # spaces) so the word boundary detection works properly. [MAP]

        if self.state == ProbingState.NOT_ME:
            # Both model probers say it's not them. No reason to continue.
            return ProbingState.NOT_ME

        byte_str = self.filter_high_byte_only(byte_str)

        for cur in byte_str:
            if cur == ' ':
                # We stand on a space - a word just ended
                if self._before_prev != ' ':
                    # next-to-last char was not a space so self._prev is not a
                    # 1 letter word
                    if self.is_final(self._prev):
                        # case (1) [-2:not space][-1:final letter][cur:space]
                        self._final_char_logical_score += 1
                    elif self.is_non_final(self._prev):
                        # case (2) [-2:not space][-1:Non-Final letter][
                        #  cur:space]
                        self._final_char_visual_score += 1
            else:
                # Not standing on a space
                if ((self._before_prev == ' ') and
                        (self.is_final(self._prev)) and (cur != ' ')):
                    # case (3) [-2:space][-1:final letter][cur:not space]
                    self._final_char_visual_score += 1
            self._before_prev = self._prev
            self._prev = cur

        # Forever detecting, till the end or until both model probers return
        # ProbingState.NOT_ME (handled above)
        return ProbingState.DETECTING

    @property
    def charset_name(self):
        # Make the decision: is it Logical or Visual?
        # If the final letter score distance is dominant enough, rely on it.
        finalsub = self._final_char_logical_score - self._final_char_visual_score
        if finalsub >= self.MIN_FINAL_CHAR_DISTANCE:
            return self.LOGICAL_HEBREW_NAME
        if finalsub <= -self.MIN_FINAL_CHAR_DISTANCE:
            return self.VISUAL_HEBREW_NAME

        # It's not dominant enough, try to rely on the model scores instead.
        modelsub = (self._logical_prober.get_confidence()
                    - self._visual_prober.get_confidence())
        if modelsub > self.MIN_MODEL_DISTANCE:
            return self.LOGICAL_HEBREW_NAME
        if modelsub < -self.MIN_MODEL_DISTANCE:
            return self.VISUAL_HEBREW_NAME

        # Still no good, back to final letter distance, maybe it'll save the
        # day.
        if finalsub < 0.0:
            return self.VISUAL_HEBREW_NAME

        # (finalsub > 0 - Logical) or (don't know what to do) default to
        # Logical.
        return self.LOGICAL_HEBREW_NAME

    @property
    def language(self):
        return 'Hebrew'

    @property
    def state(self):
        # Remain active as long as any of the model probers are active.
        if (self._logical_prober.state == ProbingState.NOT_ME) and \
           (self._visual_prober.state == ProbingState.NOT_ME):
            return ProbingState.NOT_ME
        return ProbingState.DETECTING



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaskRun(object):
    """
    The information about TaskRun.
    """

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "NOT_STARTED"
    STATUS_NOT_STARTED = "NOT_STARTED"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "QUEUED"
    STATUS_QUEUED = "QUEUED"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "RUNNING"
    STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "TERMINATING"
    STATUS_TERMINATING = "TERMINATING"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "TERMINATED"
    STATUS_TERMINATED = "TERMINATED"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "SUCCESS"
    STATUS_SUCCESS = "SUCCESS"

    #: A constant which can be used with the status property of a TaskRun.
    #: This constant has a value of "ERROR"
    STATUS_ERROR = "ERROR"

    #: A constant which can be used with the task_type property of a TaskRun.
    #: This constant has a value of "INTEGRATION_TASK"
    TASK_TYPE_INTEGRATION_TASK = "INTEGRATION_TASK"

    #: A constant which can be used with the task_type property of a TaskRun.
    #: This constant has a value of "DATA_LOADER_TASK"
    TASK_TYPE_DATA_LOADER_TASK = "DATA_LOADER_TASK"

    def __init__(self, **kwargs):
        """
        Initializes a new TaskRun object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this TaskRun.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this TaskRun.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this TaskRun.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TaskRun.
        :type parent_ref: ParentReference

        :param name:
            The value to assign to the name property of this TaskRun.
        :type name: str

        :param description:
            The value to assign to the description property of this TaskRun.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this TaskRun.
        :type object_version: int

        :param config_provider:
            The value to assign to the config_provider property of this TaskRun.
        :type config_provider: ConfigProvider

        :param status:
            The value to assign to the status property of this TaskRun.
            Allowed values for this property are: "NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param start_time_millis:
            The value to assign to the start_time_millis property of this TaskRun.
        :type start_time_millis: int

        :param end_time_millis:
            The value to assign to the end_time_millis property of this TaskRun.
        :type end_time_millis: int

        :param last_updated:
            The value to assign to the last_updated property of this TaskRun.
        :type last_updated: int

        :param records_written:
            The value to assign to the records_written property of this TaskRun.
        :type records_written: int

        :param bytes_processed:
            The value to assign to the bytes_processed property of this TaskRun.
        :type bytes_processed: int

        :param error_message:
            The value to assign to the error_message property of this TaskRun.
        :type error_message: str

        :param opc_request_id:
            The value to assign to the opc_request_id property of this TaskRun.
        :type opc_request_id: str

        :param object_status:
            The value to assign to the object_status property of this TaskRun.
        :type object_status: int

        :param task_type:
            The value to assign to the task_type property of this TaskRun.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type task_type: str

        :param identifier:
            The value to assign to the identifier property of this TaskRun.
        :type identifier: str

        :param metadata:
            The value to assign to the metadata property of this TaskRun.
        :type metadata: ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this TaskRun.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'config_provider': 'ConfigProvider',
            'status': 'str',
            'start_time_millis': 'int',
            'end_time_millis': 'int',
            'last_updated': 'int',
            'records_written': 'int',
            'bytes_processed': 'int',
            'error_message': 'str',
            'opc_request_id': 'str',
            'object_status': 'int',
            'task_type': 'str',
            'identifier': 'str',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'config_provider': 'configProvider',
            'status': 'status',
            'start_time_millis': 'startTimeMillis',
            'end_time_millis': 'endTimeMillis',
            'last_updated': 'lastUpdated',
            'records_written': 'recordsWritten',
            'bytes_processed': 'bytesProcessed',
            'error_message': 'errorMessage',
            'opc_request_id': 'opcRequestId',
            'object_status': 'objectStatus',
            'task_type': 'taskType',
            'identifier': 'identifier',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._config_provider = None
        self._status = None
        self._start_time_millis = None
        self._end_time_millis = None
        self._last_updated = None
        self._records_written = None
        self._bytes_processed = None
        self._error_message = None
        self._opc_request_id = None
        self._object_status = None
        self._task_type = None
        self._identifier = None
        self._metadata = None
        self._key_map = None

    @property
    def key(self):
        """
        Gets the key of this TaskRun.
        The key of the object.


        :return: The key of this TaskRun.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TaskRun.
        The key of the object.


        :param key: The key of this TaskRun.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        Gets the model_type of this TaskRun.
        The type of the object.


        :return: The model_type of this TaskRun.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this TaskRun.
        The type of the object.


        :param model_type: The model_type of this TaskRun.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this TaskRun.
        The model version of an object.


        :return: The model_version of this TaskRun.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this TaskRun.
        The model version of an object.


        :param model_version: The model_version of this TaskRun.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this TaskRun.

        :return: The parent_ref of this TaskRun.
        :rtype: ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this TaskRun.

        :param parent_ref: The parent_ref of this TaskRun.
        :type: ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this TaskRun.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :return: The name of this TaskRun.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TaskRun.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value can be edited by the user and it is restricted to 1000 characters


        :param name: The name of this TaskRun.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TaskRun.
        Detailed description for the object.


        :return: The description of this TaskRun.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TaskRun.
        Detailed description for the object.


        :param description: The description of this TaskRun.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this TaskRun.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this TaskRun.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this TaskRun.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this TaskRun.
        :type: int
        """
        self._object_version = object_version

    @property
    def config_provider(self):
        """
        Gets the config_provider of this TaskRun.

        :return: The config_provider of this TaskRun.
        :rtype: ConfigProvider
        """
        return self._config_provider

    @config_provider.setter
    def config_provider(self, config_provider):
        """
        Sets the config_provider of this TaskRun.

        :param config_provider: The config_provider of this TaskRun.
        :type: ConfigProvider
        """
        self._config_provider = config_provider

    @property
    def status(self):
        """
        Gets the status of this TaskRun.
        status

        Allowed values for this property are: "NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this TaskRun.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this TaskRun.
        status


        :param status: The status of this TaskRun.
        :type: str
        """
        allowed_values = ["NOT_STARTED", "QUEUED", "RUNNING", "TERMINATING", "TERMINATED", "SUCCESS", "ERROR"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def start_time_millis(self):
        """
        Gets the start_time_millis of this TaskRun.
        startTimeMillis


        :return: The start_time_millis of this TaskRun.
        :rtype: int
        """
        return self._start_time_millis

    @start_time_millis.setter
    def start_time_millis(self, start_time_millis):
        """
        Sets the start_time_millis of this TaskRun.
        startTimeMillis


        :param start_time_millis: The start_time_millis of this TaskRun.
        :type: int
        """
        self._start_time_millis = start_time_millis

    @property
    def end_time_millis(self):
        """
        Gets the end_time_millis of this TaskRun.
        endTimeMillis


        :return: The end_time_millis of this TaskRun.
        :rtype: int
        """
        return self._end_time_millis

    @end_time_millis.setter
    def end_time_millis(self, end_time_millis):
        """
        Sets the end_time_millis of this TaskRun.
        endTimeMillis


        :param end_time_millis: The end_time_millis of this TaskRun.
        :type: int
        """
        self._end_time_millis = end_time_millis

    @property
    def last_updated(self):
        """
        Gets the last_updated of this TaskRun.
        lastUpdated


        :return: The last_updated of this TaskRun.
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """
        Sets the last_updated of this TaskRun.
        lastUpdated


        :param last_updated: The last_updated of this TaskRun.
        :type: int
        """
        self._last_updated = last_updated

    @property
    def records_written(self):
        """
        Gets the records_written of this TaskRun.
        Number of records processed in task run.


        :return: The records_written of this TaskRun.
        :rtype: int
        """
        return self._records_written

    @records_written.setter
    def records_written(self, records_written):
        """
        Sets the records_written of this TaskRun.
        Number of records processed in task run.


        :param records_written: The records_written of this TaskRun.
        :type: int
        """
        self._records_written = records_written

    @property
    def bytes_processed(self):
        """
        Gets the bytes_processed of this TaskRun.
        Number of bytes processed in task run.


        :return: The bytes_processed of this TaskRun.
        :rtype: int
        """
        return self._bytes_processed

    @bytes_processed.setter
    def bytes_processed(self, bytes_processed):
        """
        Sets the bytes_processed of this TaskRun.
        Number of bytes processed in task run.


        :param bytes_processed: The bytes_processed of this TaskRun.
        :type: int
        """
        self._bytes_processed = bytes_processed

    @property
    def error_message(self):
        """
        Gets the error_message of this TaskRun.
        Error message if status is ERROR


        :return: The error_message of this TaskRun.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this TaskRun.
        Error message if status is ERROR


        :param error_message: The error_message of this TaskRun.
        :type: str
        """
        self._error_message = error_message

    @property
    def opc_request_id(self):
        """
        Gets the opc_request_id of this TaskRun.
        Opc request id of execution of task run


        :return: The opc_request_id of this TaskRun.
        :rtype: str
        """
        return self._opc_request_id

    @opc_request_id.setter
    def opc_request_id(self, opc_request_id):
        """
        Sets the opc_request_id of this TaskRun.
        Opc request id of execution of task run


        :param opc_request_id: The opc_request_id of this TaskRun.
        :type: str
        """
        self._opc_request_id = opc_request_id

    @property
    def object_status(self):
        """
        Gets the object_status of this TaskRun.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this TaskRun.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this TaskRun.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this TaskRun.
        :type: int
        """
        self._object_status = object_status

    @property
    def task_type(self):
        """
        Gets the task_type of this TaskRun.
        The type of the task for the run.

        Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The task_type of this TaskRun.
        :rtype: str
        """
        return self._task_type

    @task_type.setter
    def task_type(self, task_type):
        """
        Sets the task_type of this TaskRun.
        The type of the task for the run.


        :param task_type: The task_type of this TaskRun.
        :type: str
        """
        allowed_values = ["INTEGRATION_TASK", "DATA_LOADER_TASK"]
        if not value_allowed_none_or_none_sentinel(task_type, allowed_values):
            task_type = 'UNKNOWN_ENUM_VALUE'
        self._task_type = task_type

    @property
    def identifier(self):
        """
        Gets the identifier of this TaskRun.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :return: The identifier of this TaskRun.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this TaskRun.
        Value can only contain upper case letters, underscore and numbers. It should begin with upper case letter or underscore. The value can be edited by the user.


        :param identifier: The identifier of this TaskRun.
        :type: str
        """
        self._identifier = identifier

    @property
    def metadata(self):
        """
        Gets the metadata of this TaskRun.

        :return: The metadata of this TaskRun.
        :rtype: ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TaskRun.

        :param metadata: The metadata of this TaskRun.
        :type: ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this TaskRun.
        A map, if provided key is replaced with generated key, this structure provides mapping between user provided key and generated key


        :return: The key_map of this TaskRun.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this TaskRun.
        A map, if provided key is replaced with generated key, this structure provides mapping between user provided key and generated key


        :param key_map: The key_map of this TaskRun.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .source_details import SourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OcicSourceDetails(SourceDetails):
    """
    Specifies configuration specific to the source environment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new OcicSourceDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.application_migration.models.OcicSourceDetails.type` attribute
        of this class is ``OCIC`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this OcicSourceDetails.
            Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE"
        :type type: str

        :param region:
            The value to assign to the region property of this OcicSourceDetails.
        :type region: str

        :param compute_account:
            The value to assign to the compute_account property of this OcicSourceDetails.
        :type compute_account: str

        """
        self.swagger_types = {
            'type': 'str',
            'region': 'str',
            'compute_account': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'region': 'region',
            'compute_account': 'computeAccount'
        }

        self._type = None
        self._region = None
        self._compute_account = None
        self._type = 'OCIC'

    @property
    def region(self):
        """
        **[Required]** Gets the region of this OcicSourceDetails.
        The Oracle Cloud Infrastructure - Classic region name (e.g. us2-z11 or uscom-central-1)


        :return: The region of this OcicSourceDetails.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this OcicSourceDetails.
        The Oracle Cloud Infrastructure - Classic region name (e.g. us2-z11 or uscom-central-1)


        :param region: The region of this OcicSourceDetails.
        :type: str
        """
        self._region = region

    @property
    def compute_account(self):
        """
        **[Required]** Gets the compute_account of this OcicSourceDetails.
        The compute account id


        :return: The compute_account of this OcicSourceDetails.
        :rtype: str
        """
        return self._compute_account

    @compute_account.setter
    def compute_account(self, compute_account):
        """
        Sets the compute_account of this OcicSourceDetails.
        The compute account id


        :param compute_account: The compute_account of this OcicSourceDetails.
        :type: str
        """
        self._compute_account = compute_account

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TcpConnection(object):
    """
    TCP connection results.  All durations are in milliseconds.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TcpConnection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param address:
            The value to assign to the address property of this TcpConnection.
        :type address: str

        :param port:
            The value to assign to the port property of this TcpConnection.
        :type port: int

        :param connect_duration:
            The value to assign to the connect_duration property of this TcpConnection.
        :type connect_duration: float

        :param secure_connect_duration:
            The value to assign to the secure_connect_duration property of this TcpConnection.
        :type secure_connect_duration: float

        """
        self.swagger_types = {
            'address': 'str',
            'port': 'int',
            'connect_duration': 'float',
            'secure_connect_duration': 'float'
        }

        self.attribute_map = {
            'address': 'address',
            'port': 'port',
            'connect_duration': 'connectDuration',
            'secure_connect_duration': 'secureConnectDuration'
        }

        self._address = None
        self._port = None
        self._connect_duration = None
        self._secure_connect_duration = None

    @property
    def address(self):
        """
        Gets the address of this TcpConnection.
        The connection IP address.


        :return: The address of this TcpConnection.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this TcpConnection.
        The connection IP address.


        :param address: The address of this TcpConnection.
        :type: str
        """
        self._address = address

    @property
    def port(self):
        """
        Gets the port of this TcpConnection.
        The port.


        :return: The port of this TcpConnection.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this TcpConnection.
        The port.


        :param port: The port of this TcpConnection.
        :type: int
        """
        self._port = port

    @property
    def connect_duration(self):
        """
        Gets the connect_duration of this TcpConnection.
        Total connect duration, calculated using `connectEnd` minus `connectStart`.


        :return: The connect_duration of this TcpConnection.
        :rtype: float
        """
        return self._connect_duration

    @connect_duration.setter
    def connect_duration(self, connect_duration):
        """
        Sets the connect_duration of this TcpConnection.
        Total connect duration, calculated using `connectEnd` minus `connectStart`.


        :param connect_duration: The connect_duration of this TcpConnection.
        :type: float
        """
        self._connect_duration = connect_duration

    @property
    def secure_connect_duration(self):
        """
        Gets the secure_connect_duration of this TcpConnection.
        The duration to secure the connection.  This value will be zero for
        insecure connections.  Calculated using `connectEnd` minus `secureConnectionStart`.


        :return: The secure_connect_duration of this TcpConnection.
        :rtype: float
        """
        return self._secure_connect_duration

    @secure_connect_duration.setter
    def secure_connect_duration(self, secure_connect_duration):
        """
        Sets the secure_connect_duration of this TcpConnection.
        The duration to secure the connection.  This value will be zero for
        insecure connections.  Calculated using `connectEnd` minus `secureConnectionStart`.


        :param secure_connect_duration: The secure_connect_duration of this TcpConnection.
        :type: float
        """
        self._secure_connect_duration = secure_connect_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterSummary(object):
    """
    The properties that define a cluster summary.
    """

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ClusterSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ClusterSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this ClusterSummary.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ClusterSummary.
        :type compartment_id: str

        :param vcn_id:
            The value to assign to the vcn_id property of this ClusterSummary.
        :type vcn_id: str

        :param kubernetes_version:
            The value to assign to the kubernetes_version property of this ClusterSummary.
        :type kubernetes_version: str

        :param options:
            The value to assign to the options property of this ClusterSummary.
        :type options: ClusterCreateOptions

        :param metadata:
            The value to assign to the metadata property of this ClusterSummary.
        :type metadata: ClusterMetadata

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ClusterSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this ClusterSummary.
        :type lifecycle_details: str

        :param endpoints:
            The value to assign to the endpoints property of this ClusterSummary.
        :type endpoints: ClusterEndpoints

        :param available_kubernetes_upgrades:
            The value to assign to the available_kubernetes_upgrades property of this ClusterSummary.
        :type available_kubernetes_upgrades: list[str]

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'vcn_id': 'str',
            'kubernetes_version': 'str',
            'options': 'ClusterCreateOptions',
            'metadata': 'ClusterMetadata',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'endpoints': 'ClusterEndpoints',
            'available_kubernetes_upgrades': 'list[str]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'vcn_id': 'vcnId',
            'kubernetes_version': 'kubernetesVersion',
            'options': 'options',
            'metadata': 'metadata',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'endpoints': 'endpoints',
            'available_kubernetes_upgrades': 'availableKubernetesUpgrades'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._vcn_id = None
        self._kubernetes_version = None
        self._options = None
        self._metadata = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._endpoints = None
        self._available_kubernetes_upgrades = None

    @property
    def id(self):
        """
        Gets the id of this ClusterSummary.
        The OCID of the cluster.


        :return: The id of this ClusterSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ClusterSummary.
        The OCID of the cluster.


        :param id: The id of this ClusterSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ClusterSummary.
        The name of the cluster.


        :return: The name of this ClusterSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ClusterSummary.
        The name of the cluster.


        :param name: The name of this ClusterSummary.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this ClusterSummary.
        The OCID of the compartment in which the cluster exists.


        :return: The compartment_id of this ClusterSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ClusterSummary.
        The OCID of the compartment in which the cluster exists.


        :param compartment_id: The compartment_id of this ClusterSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def vcn_id(self):
        """
        Gets the vcn_id of this ClusterSummary.
        The OCID of the virtual cloud network (VCN) in which the cluster exists


        :return: The vcn_id of this ClusterSummary.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this ClusterSummary.
        The OCID of the virtual cloud network (VCN) in which the cluster exists


        :param vcn_id: The vcn_id of this ClusterSummary.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def kubernetes_version(self):
        """
        Gets the kubernetes_version of this ClusterSummary.
        The version of Kubernetes running on the cluster masters.


        :return: The kubernetes_version of this ClusterSummary.
        :rtype: str
        """
        return self._kubernetes_version

    @kubernetes_version.setter
    def kubernetes_version(self, kubernetes_version):
        """
        Sets the kubernetes_version of this ClusterSummary.
        The version of Kubernetes running on the cluster masters.


        :param kubernetes_version: The kubernetes_version of this ClusterSummary.
        :type: str
        """
        self._kubernetes_version = kubernetes_version

    @property
    def options(self):
        """
        Gets the options of this ClusterSummary.
        Optional attributes for the cluster.


        :return: The options of this ClusterSummary.
        :rtype: ClusterCreateOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """
        Sets the options of this ClusterSummary.
        Optional attributes for the cluster.


        :param options: The options of this ClusterSummary.
        :type: ClusterCreateOptions
        """
        self._options = options

    @property
    def metadata(self):
        """
        Gets the metadata of this ClusterSummary.
        Metadata about the cluster.


        :return: The metadata of this ClusterSummary.
        :rtype: ClusterMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this ClusterSummary.
        Metadata about the cluster.


        :param metadata: The metadata of this ClusterSummary.
        :type: ClusterMetadata
        """
        self._metadata = metadata

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this ClusterSummary.
        The state of the cluster masters.

        Allowed values for this property are: "CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ClusterSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ClusterSummary.
        The state of the cluster masters.


        :param lifecycle_state: The lifecycle_state of this ClusterSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "FAILED", "DELETING", "DELETED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this ClusterSummary.
        Details about the state of the cluster masters.


        :return: The lifecycle_details of this ClusterSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this ClusterSummary.
        Details about the state of the cluster masters.


        :param lifecycle_details: The lifecycle_details of this ClusterSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def endpoints(self):
        """
        Gets the endpoints of this ClusterSummary.
        Endpoints served up by the cluster masters.


        :return: The endpoints of this ClusterSummary.
        :rtype: ClusterEndpoints
        """
        return self._endpoints

    @endpoints.setter
    def endpoints(self, endpoints):
        """
        Sets the endpoints of this ClusterSummary.
        Endpoints served up by the cluster masters.


        :param endpoints: The endpoints of this ClusterSummary.
        :type: ClusterEndpoints
        """
        self._endpoints = endpoints

    @property
    def available_kubernetes_upgrades(self):
        """
        Gets the available_kubernetes_upgrades of this ClusterSummary.
        Available Kubernetes versions to which the clusters masters may be upgraded.


        :return: The available_kubernetes_upgrades of this ClusterSummary.
        :rtype: list[str]
        """
        return self._available_kubernetes_upgrades

    @available_kubernetes_upgrades.setter
    def available_kubernetes_upgrades(self, available_kubernetes_upgrades):
        """
        Sets the available_kubernetes_upgrades of this ClusterSummary.
        Available Kubernetes versions to which the clusters masters may be upgraded.


        :param available_kubernetes_upgrades: The available_kubernetes_upgrades of this ClusterSummary.
        :type: list[str]
        """
        self._available_kubernetes_upgrades = available_kubernetes_upgrades

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationCreateVnicDetails(object):
    """
    Contains the properties of the VNIC for an instance configuration. See :class:`CreateVnicDetails`
    and `Instance Configurations`__ for more information.

    __ https://docs.cloud.oracle.com/Content/Compute/Concepts/instancemanagement.htm#config
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationCreateVnicDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param assign_public_ip:
            The value to assign to the assign_public_ip property of this InstanceConfigurationCreateVnicDetails.
        :type assign_public_ip: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this InstanceConfigurationCreateVnicDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this InstanceConfigurationCreateVnicDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this InstanceConfigurationCreateVnicDetails.
        :type freeform_tags: dict(str, str)

        :param hostname_label:
            The value to assign to the hostname_label property of this InstanceConfigurationCreateVnicDetails.
        :type hostname_label: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this InstanceConfigurationCreateVnicDetails.
        :type nsg_ids: list[str]

        :param private_ip:
            The value to assign to the private_ip property of this InstanceConfigurationCreateVnicDetails.
        :type private_ip: str

        :param skip_source_dest_check:
            The value to assign to the skip_source_dest_check property of this InstanceConfigurationCreateVnicDetails.
        :type skip_source_dest_check: bool

        :param subnet_id:
            The value to assign to the subnet_id property of this InstanceConfigurationCreateVnicDetails.
        :type subnet_id: str

        """
        self.swagger_types = {
            'assign_public_ip': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'hostname_label': 'str',
            'nsg_ids': 'list[str]',
            'private_ip': 'str',
            'skip_source_dest_check': 'bool',
            'subnet_id': 'str'
        }

        self.attribute_map = {
            'assign_public_ip': 'assignPublicIp',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'hostname_label': 'hostnameLabel',
            'nsg_ids': 'nsgIds',
            'private_ip': 'privateIp',
            'skip_source_dest_check': 'skipSourceDestCheck',
            'subnet_id': 'subnetId'
        }

        self._assign_public_ip = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._hostname_label = None
        self._nsg_ids = None
        self._private_ip = None
        self._skip_source_dest_check = None
        self._subnet_id = None

    @property
    def assign_public_ip(self):
        """
        Gets the assign_public_ip of this InstanceConfigurationCreateVnicDetails.
        Whether the VNIC should be assigned a public IP address. See the `assignPublicIp` attribute of :class:`CreateVnicDetails`
        for more information.


        :return: The assign_public_ip of this InstanceConfigurationCreateVnicDetails.
        :rtype: bool
        """
        return self._assign_public_ip

    @assign_public_ip.setter
    def assign_public_ip(self, assign_public_ip):
        """
        Sets the assign_public_ip of this InstanceConfigurationCreateVnicDetails.
        Whether the VNIC should be assigned a public IP address. See the `assignPublicIp` attribute of :class:`CreateVnicDetails`
        for more information.


        :param assign_public_ip: The assign_public_ip of this InstanceConfigurationCreateVnicDetails.
        :type: bool
        """
        self._assign_public_ip = assign_public_ip

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this InstanceConfigurationCreateVnicDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this InstanceConfigurationCreateVnicDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this InstanceConfigurationCreateVnicDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this InstanceConfigurationCreateVnicDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this InstanceConfigurationCreateVnicDetails.
        A user-friendly name for the VNIC. Does not have to be unique.
        Avoid entering confidential information.


        :return: The display_name of this InstanceConfigurationCreateVnicDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstanceConfigurationCreateVnicDetails.
        A user-friendly name for the VNIC. Does not have to be unique.
        Avoid entering confidential information.


        :param display_name: The display_name of this InstanceConfigurationCreateVnicDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this InstanceConfigurationCreateVnicDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this InstanceConfigurationCreateVnicDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this InstanceConfigurationCreateVnicDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this InstanceConfigurationCreateVnicDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def hostname_label(self):
        """
        Gets the hostname_label of this InstanceConfigurationCreateVnicDetails.
        The hostname for the VNIC's primary private IP.
        See the `hostnameLabel` attribute of :class:`CreateVnicDetails` for more information.


        :return: The hostname_label of this InstanceConfigurationCreateVnicDetails.
        :rtype: str
        """
        return self._hostname_label

    @hostname_label.setter
    def hostname_label(self, hostname_label):
        """
        Sets the hostname_label of this InstanceConfigurationCreateVnicDetails.
        The hostname for the VNIC's primary private IP.
        See the `hostnameLabel` attribute of :class:`CreateVnicDetails` for more information.


        :param hostname_label: The hostname_label of this InstanceConfigurationCreateVnicDetails.
        :type: str
        """
        self._hostname_label = hostname_label

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this InstanceConfigurationCreateVnicDetails.
        A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.


        :return: The nsg_ids of this InstanceConfigurationCreateVnicDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this InstanceConfigurationCreateVnicDetails.
        A list of the OCIDs of the network security groups (NSGs) to add the VNIC to. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.


        :param nsg_ids: The nsg_ids of this InstanceConfigurationCreateVnicDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def private_ip(self):
        """
        Gets the private_ip of this InstanceConfigurationCreateVnicDetails.
        A private IP address of your choice to assign to the VNIC.
        See the `privateIp` attribute of :class:`CreateVnicDetails` for more information.


        :return: The private_ip of this InstanceConfigurationCreateVnicDetails.
        :rtype: str
        """
        return self._private_ip

    @private_ip.setter
    def private_ip(self, private_ip):
        """
        Sets the private_ip of this InstanceConfigurationCreateVnicDetails.
        A private IP address of your choice to assign to the VNIC.
        See the `privateIp` attribute of :class:`CreateVnicDetails` for more information.


        :param private_ip: The private_ip of this InstanceConfigurationCreateVnicDetails.
        :type: str
        """
        self._private_ip = private_ip

    @property
    def skip_source_dest_check(self):
        """
        Gets the skip_source_dest_check of this InstanceConfigurationCreateVnicDetails.
        Whether the source/destination check is disabled on the VNIC.
        See the `skipSourceDestCheck` attribute of :class:`CreateVnicDetails` for more information.


        :return: The skip_source_dest_check of this InstanceConfigurationCreateVnicDetails.
        :rtype: bool
        """
        return self._skip_source_dest_check

    @skip_source_dest_check.setter
    def skip_source_dest_check(self, skip_source_dest_check):
        """
        Sets the skip_source_dest_check of this InstanceConfigurationCreateVnicDetails.
        Whether the source/destination check is disabled on the VNIC.
        See the `skipSourceDestCheck` attribute of :class:`CreateVnicDetails` for more information.


        :param skip_source_dest_check: The skip_source_dest_check of this InstanceConfigurationCreateVnicDetails.
        :type: bool
        """
        self._skip_source_dest_check = skip_source_dest_check

    @property
    def subnet_id(self):
        """
        Gets the subnet_id of this InstanceConfigurationCreateVnicDetails.
        The OCID of the subnet to create the VNIC in.
        See the `subnetId` attribute of :class:`CreateVnicDetails` for more information.


        :return: The subnet_id of this InstanceConfigurationCreateVnicDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this InstanceConfigurationCreateVnicDetails.
        The OCID of the subnet to create the VNIC in.
        See the `subnetId` attribute of :class:`CreateVnicDetails` for more information.


        :param subnet_id: The subnet_id of this InstanceConfigurationCreateVnicDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class TransferPackageClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.dts.TransferPackageClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new TransferPackageClientCompositeOperations object

        :param TransferPackageClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def create_transfer_package_and_wait_for_state(self, id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.dts.TransferPackageClient.create_transfer_package` and waits for the :py:class:`~oci.dts.models.TransferPackage` acted upon
        to enter the given state(s).

        :param str id: (required)
            ID of the Transfer Job

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.dts.models.TransferPackage.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.dts.TransferPackageClient.create_transfer_package`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_transfer_package(id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_transfer_package(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_transfer_package_and_wait_for_state(self, id, transfer_package_label, update_transfer_package_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.dts.TransferPackageClient.update_transfer_package` and waits for the :py:class:`~oci.dts.models.TransferPackage` acted upon
        to enter the given state(s).

        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param UpdateTransferPackageDetails update_transfer_package_details: (required)
            fields to update

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.dts.models.TransferPackage.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.dts.TransferPackageClient.update_transfer_package`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_transfer_package(id, transfer_package_label, update_transfer_package_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_transfer_package(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .backup_location import BackupLocation
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BackupLocationURI(BackupLocation):
    """
    PreAuthenticated object storage URI to upload or download the backup
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BackupLocationURI object with values from keyword arguments. The default value of the :py:attr:`~oci.key_management.models.BackupLocationURI.destination` attribute
        of this class is ``PRE_AUTHENTICATED_REQUEST_URI`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination:
            The value to assign to the destination property of this BackupLocationURI.
            Allowed values for this property are: "BUCKET", "PRE_AUTHENTICATED_REQUEST_URI"
        :type destination: str

        :param uri:
            The value to assign to the uri property of this BackupLocationURI.
        :type uri: str

        """
        self.swagger_types = {
            'destination': 'str',
            'uri': 'str'
        }

        self.attribute_map = {
            'destination': 'destination',
            'uri': 'uri'
        }

        self._destination = None
        self._uri = None
        self._destination = 'PRE_AUTHENTICATED_REQUEST_URI'

    @property
    def uri(self):
        """
        **[Required]** Gets the uri of this BackupLocationURI.

        :return: The uri of this BackupLocationURI.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this BackupLocationURI.

        :param uri: The uri of this BackupLocationURI.
        :type: str
        """
        self._uri = uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
